@@ -10,10 +10,11 @@ require Exporter;
                 kanjidic_order
                 %codes
                 %has_dupes
+		grade
                /;
 use warnings;
 use strict;
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 use strict;
 use warnings;
 use Encode;
@@ -26,18 +27,18 @@ our %codes = (
     'W' => 'Korean pronunciation',
     'Y' => 'Pinyin pronunciation',
     'B' => 'Bushu (radical as defined by the Nelson kanji dictionary)',
-    'C' => 'Classic radical (the usual radical)',
-    'U' => 'Unicode',
+    'C' => 'Classic radical (the usual radical, where this is different from the Nelson radical)',
+    'U' => 'Unicode code point as a hexadecimal number',
     'G' => 'Year of elementary school',
-    'Q' => 'Four-corner code for the kanji',
+    'Q' => 'Four-corner code',
     'S' => 'Stroke count',
     'P' => 'SKIP code', 
-    'J' => 'Japanese proficiency test level of the kanji',
+    'J' => 'Japanese proficiency test level',
     'N' => 'Nelson code from original Nelson dictionary',
     'V' => 'Nelson code from the "New Nelson" dictionary',
     'L' => 'Code from "Remembering the Kanji" by James Heisig',
     'O' => 'The numbers used in P.G. O\'Neill\'s "Japanese Names"',
-    'K' => 'The index in the Gakken Kanji Dictionary (A New Dictionary of Kanji Usage);',
+    'K' => 'The index in the Gakken Kanji Dictionary (A New Dictionary of Kanji Usage)',
     'E' => 'The numbers used in Kenneth Henshall\'s kanji book',
     'I' => 'The Spahn-Hadamitzky book number',
     'IN' => 'The Spahn-Hadamitzky kanji-kana book number',
@@ -49,21 +50,21 @@ our %codes = (
 
     'X' => 'Cross reference',
     'DB' => 'Japanese for Busy People textbook numbers', 
-    'DC' => 'The index numbers used in "The Kanji Way to Japanese Language Power" by Dale Crowley.', 
+    'DC' => 'The index numbers used in "The Kanji Way to Japanese Language Power" by Dale Crowley', 
     'DF' => '"Japanese Kanji Flashcards", by Max Hodges and Tomoko Okazaki',
     'DG' => 'The index numbers used in the "Kodansha Compact Kanji Guide"', 
-    'DH' => 'The index numbers used in the 3rd edition of "A Guide To Reading and Writing Japanese" edited by Kenneth Hensall et al.',
-    'DJ' => 'The index numbers used in the "Kanji in Context" by Nishiguchi and Kono.', 
+    'DH' => 'The index numbers used in the 3rd edition of "A Guide To Reading and Writing Japanese" edited by Kenneth Hensall et al',
+    'DJ' => 'The index numbers used in the "Kanji in Context" by Nishiguchi and Kono', 
     'DK' => 'The index numbers used by Jack Halpern in his Kanji Learners Dictionary',
     'DM' => 'The index numbers from the French-language version of "Remembering the kanji"',
     'DO' => 'The index numbers used in P.G. O\'Neill\'s Essential Kanji',
-    'DR' => 'the codes developed by Father Joseph De Roo, and published in his book "2001 Kanji" (Bonjinsha)',
-    'DS' => 'The index numbers used in the early editions of "A Guide To Reading and Writing Japanese" edited by Florence Sakade.',
-    'DT' => 'The index numbers used in the Tuttle Kanji Cards, compiled by Alexander Kask.',
-    'XJ' => 'Cross-reference.',
-    'XO' => 'Cross-reference.',
-    'XH' => 'Cross-reference.',
-    'XI' => 'Cross-reference.',
+    'DR' => 'The codes developed by Father Joseph De Roo, and published in his book "2001 Kanji" (Bonjinsha)',
+    'DS' => 'The index numbers used in the early editions of "A Guide To Reading and Writing Japanese" edited by Florence Sakade',
+    'DT' => 'The index numbers used in the Tuttle Kanji Cards, compiled by Alexander Kask',
+    'XJ' => 'Cross-reference',
+    'XO' => 'Cross-reference',
+    'XH' => 'Cross-reference',
+    'XI' => 'Cross-reference',
     'XN' => 'Nelson cross-reference',
     'XDR' => 'De Roo cross-reference',
     'T' => 'SPECIAL',
@@ -276,7 +277,6 @@ sub parse_kanjidic
 
     open $KANJIDIC, "<:encoding(euc-jp)", $file_name
         or die "Could not open '$file_name': $!";
-    binmode STDOUT,"utf8";
     while (<$KANJIDIC>) {
         # Skip the comment line.
         next if ( m/^\#/ );
@@ -362,5 +362,17 @@ sub kanji_to_order
     return $kanjidic->{index}->{$kanji};
 }
 
+sub grade
+{
+    my ($kanjidic, $grade) = @_;
+    my @grade_kanjis;
+    for my $k (keys %$kanjidic) {
+        my $kgrade = $kanjidic->{$k}->{G};
+        next unless $kgrade;
+        push @grade_kanjis, $k if $kgrade == $grade;
+    }
+    return \@grade_kanjis;
+}
+
 1;
 
